.. This file is automatically generated/updated by a github actions workflow.
.. Every manual change will be overwritten on push to main.
.. You can find it here: ``.github/workflows/update-authors.yaml``
.. For more information see `https://github.com/cielquan/verbum/graphs/contributors`

Author
------
Christian Riedel <cielquan@protonmail.com>

Additional contributions by (sorted by name)
--------------------------------------------
